@@ -1,6 +1,5 @@
 package Log::Dispatch::Gtk2::Notify::Types;
-our $VERSION = '0.01';
-
+our $VERSION = '0.02';
 
 use MooseX::Types::Moose qw/Str/;
 use Log::Dispatch;
@@ -15,7 +14,7 @@ use MooseX::Types -declare => [qw/
 /];
 
 subtype LogLevel,
-    from Str,
+    as Str,
     where { Log::Dispatch->level_is_valid($_) },
     message { 'invalid log level' };
 
@@ -26,7 +25,6 @@ class_type Pixbuf,     { class => 'Gtk2::Gdk::Pixbuf' };
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -35,19 +33,18 @@ Log::Dispatch::Gtk2::Notify::Types
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 AUTHOR
 
-  Florian Ragwitz <rafl@debian.org>
+Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2009 by Florian Ragwitz.
+This software is copyright (c) 2010 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
-the same terms as perl itself.
-
-=cut 
+the same terms as the Perl 5 programming language system itself.
 
+=cut
 
